==> python_card_framework-2.0.0-py3-none-any.whl: card_framework/v2/__init__.py <==
# Copyright 2022 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .action_response import ActionResponse
from .action_status import ActionStatus
from .annotation import Annotation, SlashCommandMetadata, UserMentionMetadata
from .attachment import Attachment, AttachmentDataRef, DriveDataRef
from .card import Card, RenderableCard
from .card_action import CardAction
from .card_fixed_footer import CardFixedFooter
from .card_header import CardHeader
from .dialog_action import Dialog, DialogAction
from .enums import HorizontalAlignment, ImageType
from .message import MatchedUrl, Message, SlashCommand, Thread
from .section import CollapseControl, Section
from .space import Space, SpaceDetail
from .user import User
from .widget import Widget

__all__ = [
    "ActionResponse",
    "ActionStatus",
    "Annotation",
    "SlashCommandMetadata",
    "UserMentionMetadata",
    "Attachment",
    "AttachmentDataRef",
    "DriveDataRef",
    "CardAction",
    "CardFixedFooter",
    "CardHeader",
    "Card",
    "RenderableCard",
    "Dialog",
    "DialogAction",
    "HorizontalAlignment",
    "ImageType",
    "Message",
    "Thread",
    "SlashCommand",
    "MatchedUrl",
    "CollapseControl",
    "Section",
    "Space",
    "SpaceDetail",
    "User",
    "Widget",
]

==> python_card_framework-2.3.0-py3-none-any.whl: card_framework/v2/__init__.py <==
# Copyright 2022 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .action_response import ActionResponse
from .action_status import ActionStatus
from .annotation import Annotation, SlashCommandMetadata, UserMentionMetadata
from .attachment import Attachment, AttachmentDataRef, DriveDataRef
from .card import Card
from .card_action import CardAction
from .card_fixed_footer import CardFixedFooter
from .card_header import CardHeader
from .dialog_action import Dialog, DialogAction
from .enums import HorizontalAlignment, ImageType
from .message import MatchedUrl, Message, SlashCommand, Thread
from .section import CollapseControl, Section
from .space import Space, SpaceDetail
from .user import User
from .widget import Widget

__all__ = [
    "ActionResponse",
    "ActionStatus",
    "Annotation",
    "SlashCommandMetadata",
    "UserMentionMetadata",
    "Attachment",
    "AttachmentDataRef",
    "DriveDataRef",
    "CardAction",
    "CardFixedFooter",
    "CardHeader",
    "Card",
    "Dialog",
    "DialogAction",
    "HorizontalAlignment",
    "ImageType",
    "Message",
    "Thread",
    "SlashCommand",
    "MatchedUrl",
    "CollapseControl",
    "Section",
    "Space",
    "SpaceDetail",
    "User",
    "Widget",
]
